"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deepCopy = void 0;
/**
 * Makes a deep copy of the object including a copy of all the children and so on.
 * @param source source object. It can be any type
 * @param fields list of root fields that should be copied. If not sent, it will copy all the fields.
 * Note: the fields only filters the children of the source not the grandchildren.
 */
function deepCopy(source, fields) {
    var target = source;
    if (source && (typeof source === 'object' || Array.isArray(source))) {
        if (source instanceof Date)
            return new Date(source.getTime());
        target = (Array.isArray(source) ? [] : {});
        if (!fields)
            for (var field in source)
                target[field] = deepCopy(source[field]);
        else
            fields.forEach(function (field) { return (target[field] = deepCopy(source[field])); });
    }
    return target;
}
exports.deepCopy = deepCopy;
//# sourceMappingURL=tools.js.map